/* Copyright (C) 1991,96,97,2002 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, see
   <http://www.gnu.org/licenses/>.  */

#include <errno.h>
#include <time.h>

/* Return the time now, and store it in *TIMER if not NULL.  */
time_t
time (timer)
     time_t *timer;
{
  __set_errno (ENOSYS);

  if (timer != NULL)
    *timer = (time_t) -1;
  return (time_t) -1;
}
libc_hidden_def (time)

stub_warning (time)
#include <stub-tag.h>
